@@ -46,7 +46,7 @@ private:
 
 class KcmGtk: public TDECModule
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	// How to name the kde-specific gtk-rc-file
