@@ -1,3 +1,7 @@
+#if defined( HAVE_CONFIG_H )
+# include "config.h"
+#endif
+
 #include <math.h>
 #include <string.h>
 #include <gtk/gtkprogressbar.h>
